==> docker-model-1.2.0-sources.jar: annotations/io/fabric8/docker/api/model/ExecStartCheckFluentImpl.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.docker.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ExecStartCheckFluentImpl<A extends ExecStartCheckFluent<A>> extends io.fabric8.docker.api.builder.BaseFluent<A> implements ExecStartCheckFluent<A>{

    private Boolean Detach;
    private Boolean Tty;

    public ExecStartCheckFluentImpl(){
    }
    public ExecStartCheckFluentImpl(ExecStartCheck instance){
            this.withDetach(instance.getDetach()); 
            this.withTty(instance.getTty()); 
    }

    public Boolean isDetach(){
            return this.Detach;
    }

    public A withDetach(Boolean Detach){
            this.Detach=Detach; return (A) this;
    }

    public Boolean isTty(){
            return this.Tty;
    }

    public A withTty(Boolean Tty){
            this.Tty=Tty; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExecStartCheckFluentImpl that = (ExecStartCheckFluentImpl) o;
            if (Detach != null ? !Detach.equals(that.Detach) :that.Detach != null) return false;
            if (Tty != null ? !Tty.equals(that.Tty) :that.Tty != null) return false;
            return true;
    }




}

==> docker-model-1.2.2-sources.jar: annotations/io/fabric8/docker/api/model/ExecStartCheckFluentImpl.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.docker.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExecStartCheckFluentImpl<A extends ExecStartCheckFluent<A>> extends io.fabric8.docker.api.builder.BaseFluent<A> implements ExecStartCheckFluent<A>{

    private Boolean Detach;
    private Boolean Tty;

    public ExecStartCheckFluentImpl(){
    }
    public ExecStartCheckFluentImpl(ExecStartCheck instance){
            this.withDetach(instance.getDetach()); 
            this.withTty(instance.getTty()); 
    }

    public Boolean isDetach(){
            return this.Detach;
    }

    public A withDetach(Boolean Detach){
            this.Detach=Detach; return (A) this;
    }

    public Boolean hasDetach(){
            return this.Detach!=null;
    }

    public Boolean isTty(){
            return this.Tty;
    }

    public A withTty(Boolean Tty){
            this.Tty=Tty; return (A) this;
    }

    public Boolean hasTty(){
            return this.Tty!=null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExecStartCheckFluentImpl that = (ExecStartCheckFluentImpl) o;
            if (Detach != null ? !Detach.equals(that.Detach) :that.Detach != null) return false;
            if (Tty != null ? !Tty.equals(that.Tty) :that.Tty != null) return false;
            return true;
    }




}
